# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types import (
    SitemapListUsersResponse,
    SitemapListPapersResponse,
    SitemapListOverviewsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSitemaps:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_overviews(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_overviews()
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_overviews_with_all_params(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_overviews(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_overviews(self, client: AlphaxivCat) -> None:
        response = client.sitemaps.with_raw_response.list_overviews()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = response.parse()
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_overviews(self, client: AlphaxivCat) -> None:
        with client.sitemaps.with_streaming_response.list_overviews() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = response.parse()
            assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_papers(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_papers()
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_papers_with_all_params(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_papers(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_papers(self, client: AlphaxivCat) -> None:
        response = client.sitemaps.with_raw_response.list_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = response.parse()
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_papers(self, client: AlphaxivCat) -> None:
        with client.sitemaps.with_streaming_response.list_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = response.parse()
            assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_users(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_users()
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_users_with_all_params(self, client: AlphaxivCat) -> None:
        sitemap = client.sitemaps.list_users(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_users(self, client: AlphaxivCat) -> None:
        response = client.sitemaps.with_raw_response.list_users()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = response.parse()
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_users(self, client: AlphaxivCat) -> None:
        with client.sitemaps.with_streaming_response.list_users() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = response.parse()
            assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSitemaps:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_overviews(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_overviews()
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_overviews_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_overviews(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_overviews(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.sitemaps.with_raw_response.list_overviews()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = await response.parse()
        assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_overviews(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.sitemaps.with_streaming_response.list_overviews() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = await response.parse()
            assert_matches_type(SitemapListOverviewsResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_papers(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_papers()
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_papers_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_papers(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.sitemaps.with_raw_response.list_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = await response.parse()
        assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.sitemaps.with_streaming_response.list_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = await response.parse()
            assert_matches_type(SitemapListPapersResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_users(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_users()
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_users_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        sitemap = await async_client.sitemaps.list_users(
            limit="limit",
            page="page",
        )
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_users(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.sitemaps.with_raw_response.list_users()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        sitemap = await response.parse()
        assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_users(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.sitemaps.with_streaming_response.list_users() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            sitemap = await response.parse()
            assert_matches_type(SitemapListUsersResponse, sitemap, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["EmailSendWeeklyDigestParams", "Event"]


class EmailSendWeeklyDigestParams(TypedDict, total=False):
    events: Iterable[Event]
    """Custom events to include"""

    intro_text: Annotated[str, PropertyInfo(alias="introText")]
    """Custom intro message"""

    role: Literal["admin", "user"]
    """Filter by user role"""

    subject: str
    """Custom email subject"""


class Event(TypedDict, total=False):
    date: Required[str]

    description: Required[str]

    link: Required[str]

    title: Required[str]

    end_time_raw: Annotated[str, PropertyInfo(alias="endTimeRaw")]

    start_time_raw: Annotated[str, PropertyInfo(alias="startTimeRaw")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.comments.v2 import moderator_toggle_flags_params, moderator_send_feedback_params
from ....types.comments.v2.moderator_toggle_flags_response import ModeratorToggleFlagsResponse

__all__ = ["ModeratorResource", "AsyncModeratorResource"]


class ModeratorResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ModeratorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return ModeratorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ModeratorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return ModeratorResourceWithStreamingResponse(self)

    def send_feedback(
        self,
        comment: str,
        *,
        message: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Send moderator feedback to comment author

        Source file:
        `api-server/src/controllers/comments/v2/moderator-send-feedback.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/comments/v2/{comment}/moderator/send-feedback",
            body=maybe_transform({"message": message}, moderator_send_feedback_params.ModeratorSendFeedbackParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def toggle_flags(
        self,
        comment: str,
        *,
        addressed: bool | Omit = omit,
        closed: bool | Omit = omit,
        flag_addressed: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ModeratorToggleFlagsResponse:
        """
        Toggle one (or more) of a set of comment moderation flags

        Source file:
        `api-server/src/controllers/comments/v2/toggle-comment-moderation-flag.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        return self._post(
            f"/comments/v2/{comment}/moderator/toggle-flags",
            body=maybe_transform(
                {
                    "addressed": addressed,
                    "closed": closed,
                    "flag_addressed": flag_addressed,
                },
                moderator_toggle_flags_params.ModeratorToggleFlagsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ModeratorToggleFlagsResponse,
        )


class AsyncModeratorResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncModeratorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncModeratorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncModeratorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncModeratorResourceWithStreamingResponse(self)

    async def send_feedback(
        self,
        comment: str,
        *,
        message: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Send moderator feedback to comment author

        Source file:
        `api-server/src/controllers/comments/v2/moderator-send-feedback.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/comments/v2/{comment}/moderator/send-feedback",
            body=await async_maybe_transform(
                {"message": message}, moderator_send_feedback_params.ModeratorSendFeedbackParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def toggle_flags(
        self,
        comment: str,
        *,
        addressed: bool | Omit = omit,
        closed: bool | Omit = omit,
        flag_addressed: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ModeratorToggleFlagsResponse:
        """
        Toggle one (or more) of a set of comment moderation flags

        Source file:
        `api-server/src/controllers/comments/v2/toggle-comment-moderation-flag.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        return await self._post(
            f"/comments/v2/{comment}/moderator/toggle-flags",
            body=await async_maybe_transform(
                {
                    "addressed": addressed,
                    "closed": closed,
                    "flag_addressed": flag_addressed,
                },
                moderator_toggle_flags_params.ModeratorToggleFlagsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ModeratorToggleFlagsResponse,
        )


class ModeratorResourceWithRawResponse:
    def __init__(self, moderator: ModeratorResource) -> None:
        self._moderator = moderator

        self.send_feedback = to_raw_response_wrapper(
            moderator.send_feedback,
        )
        self.toggle_flags = to_raw_response_wrapper(
            moderator.toggle_flags,
        )


class AsyncModeratorResourceWithRawResponse:
    def __init__(self, moderator: AsyncModeratorResource) -> None:
        self._moderator = moderator

        self.send_feedback = async_to_raw_response_wrapper(
            moderator.send_feedback,
        )
        self.toggle_flags = async_to_raw_response_wrapper(
            moderator.toggle_flags,
        )


class ModeratorResourceWithStreamingResponse:
    def __init__(self, moderator: ModeratorResource) -> None:
        self._moderator = moderator

        self.send_feedback = to_streamed_response_wrapper(
            moderator.send_feedback,
        )
        self.toggle_flags = to_streamed_response_wrapper(
            moderator.toggle_flags,
        )


class AsyncModeratorResourceWithStreamingResponse:
    def __init__(self, moderator: AsyncModeratorResource) -> None:
        self._moderator = moderator

        self.send_feedback = async_to_streamed_response_wrapper(
            moderator.send_feedback,
        )
        self.toggle_flags = async_to_streamed_response_wrapper(
            moderator.toggle_flags,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
    not_given,
)
from ._utils import is_given, get_async_library
from ._compat import cached_property
from ._models import SecurityOptions
from ._version import __version__
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

if TYPE_CHECKING:
    from .resources import (
        mcp,
        admin,
        arxiv,
        users,
        briefs,
        emails,
        events,
        papers,
        retool,
        search,
        folders,
        wrapped,
        api_keys,
        comments,
        research,
        retrieve,
        sitemaps,
        analytics,
        assistant,
        well_known,
        notifications,
        organizations,
        google_scholar,
    )
    from .resources.emails import EmailsResource, AsyncEmailsResource
    from .resources.events import EventsResource, AsyncEventsResource
    from .resources.mcp.mcp import McpResource, AsyncMcpResource
    from .resources.wrapped import WrappedResource, AsyncWrappedResource
    from .resources.research import ResearchResource, AsyncResearchResource
    from .resources.sitemaps import SitemapsResource, AsyncSitemapsResource
    from .resources.well_known import WellKnownResource, AsyncWellKnownResource
    from .resources.admin.admin import AdminResource, AsyncAdminResource
    from .resources.arxiv.arxiv import ArxivResource, AsyncArxivResource
    from .resources.users.users import UsersResource, AsyncUsersResource
    from .resources.briefs.briefs import BriefsResource, AsyncBriefsResource
    from .resources.papers.papers import PapersResource, AsyncPapersResource
    from .resources.retool.retool import RetoolResource, AsyncRetoolResource
    from .resources.search.search import SearchResource, AsyncSearchResource
    from .resources.folders.folders import FoldersResource, AsyncFoldersResource
    from .resources.api_keys.api_keys import APIKeysResource, AsyncAPIKeysResource
    from .resources.comments.comments import CommentsResource, AsyncCommentsResource
    from .resources.retrieve.retrieve import RetrieveResource, AsyncRetrieveResource
    from .resources.analytics.analytics import AnalyticsResource, AsyncAnalyticsResource
    from .resources.assistant.assistant import AssistantResource, AsyncAssistantResource
    from .resources.notifications.notifications import NotificationsResource, AsyncNotificationsResource
    from .resources.organizations.organizations import OrganizationsResource, AsyncOrganizationsResource
    from .resources.google_scholar.google_scholar import GoogleScholarResource, AsyncGoogleScholarResource

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "AlphaxivCat",
    "AsyncAlphaxivCat",
    "Client",
    "AsyncClient",
]


class AlphaxivCat(SyncAPIClient):
    # client options
    api_key: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous AlphaxivCat client instance.

        This automatically infers the `api_key` argument from the `ALPHAXIV_CAT_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ALPHAXIV_CAT_API_KEY")
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ALPHAXIV_CAT_BASE_URL")
        if base_url is None:
            base_url = f"https://api.alphaxiv.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def papers(self) -> PapersResource:
        from .resources.papers import PapersResource

        return PapersResource(self)

    @cached_property
    def emails(self) -> EmailsResource:
        from .resources.emails import EmailsResource

        return EmailsResource(self)

    @cached_property
    def users(self) -> UsersResource:
        from .resources.users import UsersResource

        return UsersResource(self)

    @cached_property
    def assistant(self) -> AssistantResource:
        from .resources.assistant import AssistantResource

        return AssistantResource(self)

    @cached_property
    def folders(self) -> FoldersResource:
        from .resources.folders import FoldersResource

        return FoldersResource(self)

    @cached_property
    def comments(self) -> CommentsResource:
        from .resources.comments import CommentsResource

        return CommentsResource(self)

    @cached_property
    def analytics(self) -> AnalyticsResource:
        from .resources.analytics import AnalyticsResource

        return AnalyticsResource(self)

    @cached_property
    def search(self) -> SearchResource:
        from .resources.search import SearchResource

        return SearchResource(self)

    @cached_property
    def organizations(self) -> OrganizationsResource:
        from .resources.organizations import OrganizationsResource

        return OrganizationsResource(self)

    @cached_property
    def google_scholar(self) -> GoogleScholarResource:
        from .resources.google_scholar import GoogleScholarResource

        return GoogleScholarResource(self)

    @cached_property
    def arxiv(self) -> ArxivResource:
        from .resources.arxiv import ArxivResource

        return ArxivResource(self)

    @cached_property
    def api_keys(self) -> APIKeysResource:
        from .resources.api_keys import APIKeysResource

        return APIKeysResource(self)

    @cached_property
    def admin(self) -> AdminResource:
        from .resources.admin import AdminResource

        return AdminResource(self)

    @cached_property
    def wrapped(self) -> WrappedResource:
        from .resources.wrapped import WrappedResource

        return WrappedResource(self)

    @cached_property
    def notifications(self) -> NotificationsResource:
        from .resources.notifications import NotificationsResource

        return NotificationsResource(self)

    @cached_property
    def sitemaps(self) -> SitemapsResource:
        from .resources.sitemaps import SitemapsResource

        return SitemapsResource(self)

    @cached_property
    def retrieve(self) -> RetrieveResource:
        from .resources.retrieve import RetrieveResource

        return RetrieveResource(self)

    @cached_property
    def retool(self) -> RetoolResource:
        from .resources.retool import RetoolResource

        return RetoolResource(self)

    @cached_property
    def briefs(self) -> BriefsResource:
        from .resources.briefs import BriefsResource

        return BriefsResource(self)

    @cached_property
    def research(self) -> ResearchResource:
        from .resources.research import ResearchResource

        return ResearchResource(self)

    @cached_property
    def mcp(self) -> McpResource:
        from .resources.mcp import McpResource

        return McpResource(self)

    @cached_property
    def events(self) -> EventsResource:
        from .resources.events import EventsResource

        return EventsResource(self)

    @cached_property
    def well_known(self) -> WellKnownResource:
        from .resources.well_known import WellKnownResource

        return WellKnownResource(self)

    @cached_property
    def with_raw_response(self) -> AlphaxivCatWithRawResponse:
        return AlphaxivCatWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AlphaxivCatWithStreamedResponse:
        return AlphaxivCatWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @override
    def _auth_headers(self, security: SecurityOptions) -> dict[str, str]:
        return {
            **(self._api_key if security.get("api_key", False) else {}),
        }

    @property
    def _api_key(self) -> dict[str, str]:
        api_key = self.api_key
        if api_key is None:
            return {}
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncAlphaxivCat(AsyncAPIClient):
    # client options
    api_key: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncAlphaxivCat client instance.

        This automatically infers the `api_key` argument from the `ALPHAXIV_CAT_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ALPHAXIV_CAT_API_KEY")
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ALPHAXIV_CAT_BASE_URL")
        if base_url is None:
            base_url = f"https://api.alphaxiv.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def papers(self) -> AsyncPapersResource:
        from .resources.papers import AsyncPapersResource

        return AsyncPapersResource(self)

    @cached_property
    def emails(self) -> AsyncEmailsResource:
        from .resources.emails import AsyncEmailsResource

        return AsyncEmailsResource(self)

    @cached_property
    def users(self) -> AsyncUsersResource:
        from .resources.users import AsyncUsersResource

        return AsyncUsersResource(self)

    @cached_property
    def assistant(self) -> AsyncAssistantResource:
        from .resources.assistant import AsyncAssistantResource

        return AsyncAssistantResource(self)

    @cached_property
    def folders(self) -> AsyncFoldersResource:
        from .resources.folders import AsyncFoldersResource

        return AsyncFoldersResource(self)

    @cached_property
    def comments(self) -> AsyncCommentsResource:
        from .resources.comments import AsyncCommentsResource

        return AsyncCommentsResource(self)

    @cached_property
    def analytics(self) -> AsyncAnalyticsResource:
        from .resources.analytics import AsyncAnalyticsResource

        return AsyncAnalyticsResource(self)

    @cached_property
    def search(self) -> AsyncSearchResource:
        from .resources.search import AsyncSearchResource

        return AsyncSearchResource(self)

    @cached_property
    def organizations(self) -> AsyncOrganizationsResource:
        from .resources.organizations import AsyncOrganizationsResource

        return AsyncOrganizationsResource(self)

    @cached_property
    def google_scholar(self) -> AsyncGoogleScholarResource:
        from .resources.google_scholar import AsyncGoogleScholarResource

        return AsyncGoogleScholarResource(self)

    @cached_property
    def arxiv(self) -> AsyncArxivResource:
        from .resources.arxiv import AsyncArxivResource

        return AsyncArxivResource(self)

    @cached_property
    def api_keys(self) -> AsyncAPIKeysResource:
        from .resources.api_keys import AsyncAPIKeysResource

        return AsyncAPIKeysResource(self)

    @cached_property
    def admin(self) -> AsyncAdminResource:
        from .resources.admin import AsyncAdminResource

        return AsyncAdminResource(self)

    @cached_property
    def wrapped(self) -> AsyncWrappedResource:
        from .resources.wrapped import AsyncWrappedResource

        return AsyncWrappedResource(self)

    @cached_property
    def notifications(self) -> AsyncNotificationsResource:
        from .resources.notifications import AsyncNotificationsResource

        return AsyncNotificationsResource(self)

    @cached_property
    def sitemaps(self) -> AsyncSitemapsResource:
        from .resources.sitemaps import AsyncSitemapsResource

        return AsyncSitemapsResource(self)

    @cached_property
    def retrieve(self) -> AsyncRetrieveResource:
        from .resources.retrieve import AsyncRetrieveResource

        return AsyncRetrieveResource(self)

    @cached_property
    def retool(self) -> AsyncRetoolResource:
        from .resources.retool import AsyncRetoolResource

        return AsyncRetoolResource(self)

    @cached_property
    def briefs(self) -> AsyncBriefsResource:
        from .resources.briefs import AsyncBriefsResource

        return AsyncBriefsResource(self)

    @cached_property
    def research(self) -> AsyncResearchResource:
        from .resources.research import AsyncResearchResource

        return AsyncResearchResource(self)

    @cached_property
    def mcp(self) -> AsyncMcpResource:
        from .resources.mcp import AsyncMcpResource

        return AsyncMcpResource(self)

    @cached_property
    def events(self) -> AsyncEventsResource:
        from .resources.events import AsyncEventsResource

        return AsyncEventsResource(self)

    @cached_property
    def well_known(self) -> AsyncWellKnownResource:
        from .resources.well_known import AsyncWellKnownResource

        return AsyncWellKnownResource(self)

    @cached_property
    def with_raw_response(self) -> AsyncAlphaxivCatWithRawResponse:
        return AsyncAlphaxivCatWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAlphaxivCatWithStreamedResponse:
        return AsyncAlphaxivCatWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @override
    def _auth_headers(self, security: SecurityOptions) -> dict[str, str]:
        return {
            **(self._api_key if security.get("api_key", False) else {}),
        }

    @property
    def _api_key(self) -> dict[str, str]:
        api_key = self.api_key
        if api_key is None:
            return {}
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AlphaxivCatWithRawResponse:
    _client: AlphaxivCat

    def __init__(self, client: AlphaxivCat) -> None:
        self._client = client

    @cached_property
    def papers(self) -> papers.PapersResourceWithRawResponse:
        from .resources.papers import PapersResourceWithRawResponse

        return PapersResourceWithRawResponse(self._client.papers)

    @cached_property
    def emails(self) -> emails.EmailsResourceWithRawResponse:
        from .resources.emails import EmailsResourceWithRawResponse

        return EmailsResourceWithRawResponse(self._client.emails)

    @cached_property
    def users(self) -> users.UsersResourceWithRawResponse:
        from .resources.users import UsersResourceWithRawResponse

        return UsersResourceWithRawResponse(self._client.users)

    @cached_property
    def assistant(self) -> assistant.AssistantResourceWithRawResponse:
        from .resources.assistant import AssistantResourceWithRawResponse

        return AssistantResourceWithRawResponse(self._client.assistant)

    @cached_property
    def folders(self) -> folders.FoldersResourceWithRawResponse:
        from .resources.folders import FoldersResourceWithRawResponse

        return FoldersResourceWithRawResponse(self._client.folders)

    @cached_property
    def comments(self) -> comments.CommentsResourceWithRawResponse:
        from .resources.comments import CommentsResourceWithRawResponse

        return CommentsResourceWithRawResponse(self._client.comments)

    @cached_property
    def analytics(self) -> analytics.AnalyticsResourceWithRawResponse:
        from .resources.analytics import AnalyticsResourceWithRawResponse

        return AnalyticsResourceWithRawResponse(self._client.analytics)

    @cached_property
    def search(self) -> search.SearchResourceWithRawResponse:
        from .resources.search import SearchResourceWithRawResponse

        return SearchResourceWithRawResponse(self._client.search)

    @cached_property
    def organizations(self) -> organizations.OrganizationsResourceWithRawResponse:
        from .resources.organizations import OrganizationsResourceWithRawResponse

        return OrganizationsResourceWithRawResponse(self._client.organizations)

    @cached_property
    def google_scholar(self) -> google_scholar.GoogleScholarResourceWithRawResponse:
        from .resources.google_scholar import GoogleScholarResourceWithRawResponse

        return GoogleScholarResourceWithRawResponse(self._client.google_scholar)

    @cached_property
    def arxiv(self) -> arxiv.ArxivResourceWithRawResponse:
        from .resources.arxiv import ArxivResourceWithRawResponse

        return ArxivResourceWithRawResponse(self._client.arxiv)

    @cached_property
    def api_keys(self) -> api_keys.APIKeysResourceWithRawResponse:
        from .resources.api_keys import APIKeysResourceWithRawResponse

        return APIKeysResourceWithRawResponse(self._client.api_keys)

    @cached_property
    def admin(self) -> admin.AdminResourceWithRawResponse:
        from .resources.admin import AdminResourceWithRawResponse

        return AdminResourceWithRawResponse(self._client.admin)

    @cached_property
    def wrapped(self) -> wrapped.WrappedResourceWithRawResponse:
        from .resources.wrapped import WrappedResourceWithRawResponse

        return WrappedResourceWithRawResponse(self._client.wrapped)

    @cached_property
    def notifications(self) -> notifications.NotificationsResourceWithRawResponse:
        from .resources.notifications import NotificationsResourceWithRawResponse

        return NotificationsResourceWithRawResponse(self._client.notifications)

    @cached_property
    def sitemaps(self) -> sitemaps.SitemapsResourceWithRawResponse:
        from .resources.sitemaps import SitemapsResourceWithRawResponse

        return SitemapsResourceWithRawResponse(self._client.sitemaps)

    @cached_property
    def retrieve(self) -> retrieve.RetrieveResourceWithRawResponse:
        from .resources.retrieve import RetrieveResourceWithRawResponse

        return RetrieveResourceWithRawResponse(self._client.retrieve)

    @cached_property
    def retool(self) -> retool.RetoolResourceWithRawResponse:
        from .resources.retool import RetoolResourceWithRawResponse

        return RetoolResourceWithRawResponse(self._client.retool)

    @cached_property
    def briefs(self) -> briefs.BriefsResourceWithRawResponse:
        from .resources.briefs import BriefsResourceWithRawResponse

        return BriefsResourceWithRawResponse(self._client.briefs)

    @cached_property
    def research(self) -> research.ResearchResourceWithRawResponse:
        from .resources.research import ResearchResourceWithRawResponse

        return ResearchResourceWithRawResponse(self._client.research)

    @cached_property
    def mcp(self) -> mcp.McpResourceWithRawResponse:
        from .resources.mcp import McpResourceWithRawResponse

        return McpResourceWithRawResponse(self._client.mcp)

    @cached_property
    def events(self) -> events.EventsResourceWithRawResponse:
        from .resources.events import EventsResourceWithRawResponse

        return EventsResourceWithRawResponse(self._client.events)

    @cached_property
    def well_known(self) -> well_known.WellKnownResourceWithRawResponse:
        from .resources.well_known import WellKnownResourceWithRawResponse

        return WellKnownResourceWithRawResponse(self._client.well_known)


class AsyncAlphaxivCatWithRawResponse:
    _client: AsyncAlphaxivCat

    def __init__(self, client: AsyncAlphaxivCat) -> None:
        self._client = client

    @cached_property
    def papers(self) -> papers.AsyncPapersResourceWithRawResponse:
        from .resources.papers import AsyncPapersResourceWithRawResponse

        return AsyncPapersResourceWithRawResponse(self._client.papers)

    @cached_property
    def emails(self) -> emails.AsyncEmailsResourceWithRawResponse:
        from .resources.emails import AsyncEmailsResourceWithRawResponse

        return AsyncEmailsResourceWithRawResponse(self._client.emails)

    @cached_property
    def users(self) -> users.AsyncUsersResourceWithRawResponse:
        from .resources.users import AsyncUsersResourceWithRawResponse

        return AsyncUsersResourceWithRawResponse(self._client.users)

    @cached_property
    def assistant(self) -> assistant.AsyncAssistantResourceWithRawResponse:
        from .resources.assistant import AsyncAssistantResourceWithRawResponse

        return AsyncAssistantResourceWithRawResponse(self._client.assistant)

    @cached_property
    def folders(self) -> folders.AsyncFoldersResourceWithRawResponse:
        from .resources.folders import AsyncFoldersResourceWithRawResponse

        return AsyncFoldersResourceWithRawResponse(self._client.folders)

    @cached_property
    def comments(self) -> comments.AsyncCommentsResourceWithRawResponse:
        from .resources.comments import AsyncCommentsResourceWithRawResponse

        return AsyncCommentsResourceWithRawResponse(self._client.comments)

    @cached_property
    def analytics(self) -> analytics.AsyncAnalyticsResourceWithRawResponse:
        from .resources.analytics import AsyncAnalyticsResourceWithRawResponse

        return AsyncAnalyticsResourceWithRawResponse(self._client.analytics)

    @cached_property
    def search(self) -> search.AsyncSearchResourceWithRawResponse:
        from .resources.search import AsyncSearchResourceWithRawResponse

        return AsyncSearchResourceWithRawResponse(self._client.search)

    @cached_property
    def organizations(self) -> organizations.AsyncOrganizationsResourceWithRawResponse:
        from .resources.organizations import AsyncOrganizationsResourceWithRawResponse

        return AsyncOrganizationsResourceWithRawResponse(self._client.organizations)

    @cached_property
    def google_scholar(self) -> google_scholar.AsyncGoogleScholarResourceWithRawResponse:
        from .resources.google_scholar import AsyncGoogleScholarResourceWithRawResponse

        return AsyncGoogleScholarResourceWithRawResponse(self._client.google_scholar)

    @cached_property
    def arxiv(self) -> arxiv.AsyncArxivResourceWithRawResponse:
        from .resources.arxiv import AsyncArxivResourceWithRawResponse

        return AsyncArxivResourceWithRawResponse(self._client.arxiv)

    @cached_property
    def api_keys(self) -> api_keys.AsyncAPIKeysResourceWithRawResponse:
        from .resources.api_keys import AsyncAPIKeysResourceWithRawResponse

        return AsyncAPIKeysResourceWithRawResponse(self._client.api_keys)

    @cached_property
    def admin(self) -> admin.AsyncAdminResourceWithRawResponse:
        from .resources.admin import AsyncAdminResourceWithRawResponse

        return AsyncAdminResourceWithRawResponse(self._client.admin)

    @cached_property
    def wrapped(self) -> wrapped.AsyncWrappedResourceWithRawResponse:
        from .resources.wrapped import AsyncWrappedResourceWithRawResponse

        return AsyncWrappedResourceWithRawResponse(self._client.wrapped)

    @cached_property
    def notifications(self) -> notifications.AsyncNotificationsResourceWithRawResponse:
        from .resources.notifications import AsyncNotificationsResourceWithRawResponse

        return AsyncNotificationsResourceWithRawResponse(self._client.notifications)

    @cached_property
    def sitemaps(self) -> sitemaps.AsyncSitemapsResourceWithRawResponse:
        from .resources.sitemaps import AsyncSitemapsResourceWithRawResponse

        return AsyncSitemapsResourceWithRawResponse(self._client.sitemaps)

    @cached_property
    def retrieve(self) -> retrieve.AsyncRetrieveResourceWithRawResponse:
        from .resources.retrieve import AsyncRetrieveResourceWithRawResponse

        return AsyncRetrieveResourceWithRawResponse(self._client.retrieve)

    @cached_property
    def retool(self) -> retool.AsyncRetoolResourceWithRawResponse:
        from .resources.retool import AsyncRetoolResourceWithRawResponse

        return AsyncRetoolResourceWithRawResponse(self._client.retool)

    @cached_property
    def briefs(self) -> briefs.AsyncBriefsResourceWithRawResponse:
        from .resources.briefs import AsyncBriefsResourceWithRawResponse

        return AsyncBriefsResourceWithRawResponse(self._client.briefs)

    @cached_property
    def research(self) -> research.AsyncResearchResourceWithRawResponse:
        from .resources.research import AsyncResearchResourceWithRawResponse

        return AsyncResearchResourceWithRawResponse(self._client.research)

    @cached_property
    def mcp(self) -> mcp.AsyncMcpResourceWithRawResponse:
        from .resources.mcp import AsyncMcpResourceWithRawResponse

        return AsyncMcpResourceWithRawResponse(self._client.mcp)

    @cached_property
    def events(self) -> events.AsyncEventsResourceWithRawResponse:
        from .resources.events import AsyncEventsResourceWithRawResponse

        return AsyncEventsResourceWithRawResponse(self._client.events)

    @cached_property
    def well_known(self) -> well_known.AsyncWellKnownResourceWithRawResponse:
        from .resources.well_known import AsyncWellKnownResourceWithRawResponse

        return AsyncWellKnownResourceWithRawResponse(self._client.well_known)


class AlphaxivCatWithStreamedResponse:
    _client: AlphaxivCat

    def __init__(self, client: AlphaxivCat) -> None:
        self._client = client

    @cached_property
    def papers(self) -> papers.PapersResourceWithStreamingResponse:
        from .resources.papers import PapersResourceWithStreamingResponse

        return PapersResourceWithStreamingResponse(self._client.papers)

    @cached_property
    def emails(self) -> emails.EmailsResourceWithStreamingResponse:
        from .resources.emails import EmailsResourceWithStreamingResponse

        return EmailsResourceWithStreamingResponse(self._client.emails)

    @cached_property
    def users(self) -> users.UsersResourceWithStreamingResponse:
        from .resources.users import UsersResourceWithStreamingResponse

        return UsersResourceWithStreamingResponse(self._client.users)

    @cached_property
    def assistant(self) -> assistant.AssistantResourceWithStreamingResponse:
        from .resources.assistant import AssistantResourceWithStreamingResponse

        return AssistantResourceWithStreamingResponse(self._client.assistant)

    @cached_property
    def folders(self) -> folders.FoldersResourceWithStreamingResponse:
        from .resources.folders import FoldersResourceWithStreamingResponse

        return FoldersResourceWithStreamingResponse(self._client.folders)

    @cached_property
    def comments(self) -> comments.CommentsResourceWithStreamingResponse:
        from .resources.comments import CommentsResourceWithStreamingResponse

        return CommentsResourceWithStreamingResponse(self._client.comments)

    @cached_property
    def analytics(self) -> analytics.AnalyticsResourceWithStreamingResponse:
        from .resources.analytics import AnalyticsResourceWithStreamingResponse

        return AnalyticsResourceWithStreamingResponse(self._client.analytics)

    @cached_property
    def search(self) -> search.SearchResourceWithStreamingResponse:
        from .resources.search import SearchResourceWithStreamingResponse

        return SearchResourceWithStreamingResponse(self._client.search)

    @cached_property
    def organizations(self) -> organizations.OrganizationsResourceWithStreamingResponse:
        from .resources.organizations import OrganizationsResourceWithStreamingResponse

        return OrganizationsResourceWithStreamingResponse(self._client.organizations)

    @cached_property
    def google_scholar(self) -> google_scholar.GoogleScholarResourceWithStreamingResponse:
        from .resources.google_scholar import GoogleScholarResourceWithStreamingResponse

        return GoogleScholarResourceWithStreamingResponse(self._client.google_scholar)

    @cached_property
    def arxiv(self) -> arxiv.ArxivResourceWithStreamingResponse:
        from .resources.arxiv import ArxivResourceWithStreamingResponse

        return ArxivResourceWithStreamingResponse(self._client.arxiv)

    @cached_property
    def api_keys(self) -> api_keys.APIKeysResourceWithStreamingResponse:
        from .resources.api_keys import APIKeysResourceWithStreamingResponse

        return APIKeysResourceWithStreamingResponse(self._client.api_keys)

    @cached_property
    def admin(self) -> admin.AdminResourceWithStreamingResponse:
        from .resources.admin import AdminResourceWithStreamingResponse

        return AdminResourceWithStreamingResponse(self._client.admin)

    @cached_property
    def wrapped(self) -> wrapped.WrappedResourceWithStreamingResponse:
        from .resources.wrapped import WrappedResourceWithStreamingResponse

        return WrappedResourceWithStreamingResponse(self._client.wrapped)

    @cached_property
    def notifications(self) -> notifications.NotificationsResourceWithStreamingResponse:
        from .resources.notifications import NotificationsResourceWithStreamingResponse

        return NotificationsResourceWithStreamingResponse(self._client.notifications)

    @cached_property
    def sitemaps(self) -> sitemaps.SitemapsResourceWithStreamingResponse:
        from .resources.sitemaps import SitemapsResourceWithStreamingResponse

        return SitemapsResourceWithStreamingResponse(self._client.sitemaps)

    @cached_property
    def retrieve(self) -> retrieve.RetrieveResourceWithStreamingResponse:
        from .resources.retrieve import RetrieveResourceWithStreamingResponse

        return RetrieveResourceWithStreamingResponse(self._client.retrieve)

    @cached_property
    def retool(self) -> retool.RetoolResourceWithStreamingResponse:
        from .resources.retool import RetoolResourceWithStreamingResponse

        return RetoolResourceWithStreamingResponse(self._client.retool)

    @cached_property
    def briefs(self) -> briefs.BriefsResourceWithStreamingResponse:
        from .resources.briefs import BriefsResourceWithStreamingResponse

        return BriefsResourceWithStreamingResponse(self._client.briefs)

    @cached_property
    def research(self) -> research.ResearchResourceWithStreamingResponse:
        from .resources.research import ResearchResourceWithStreamingResponse

        return ResearchResourceWithStreamingResponse(self._client.research)

    @cached_property
    def mcp(self) -> mcp.McpResourceWithStreamingResponse:
        from .resources.mcp import McpResourceWithStreamingResponse

        return McpResourceWithStreamingResponse(self._client.mcp)

    @cached_property
    def events(self) -> events.EventsResourceWithStreamingResponse:
        from .resources.events import EventsResourceWithStreamingResponse

        return EventsResourceWithStreamingResponse(self._client.events)

    @cached_property
    def well_known(self) -> well_known.WellKnownResourceWithStreamingResponse:
        from .resources.well_known import WellKnownResourceWithStreamingResponse

        return WellKnownResourceWithStreamingResponse(self._client.well_known)


class AsyncAlphaxivCatWithStreamedResponse:
    _client: AsyncAlphaxivCat

    def __init__(self, client: AsyncAlphaxivCat) -> None:
        self._client = client

    @cached_property
    def papers(self) -> papers.AsyncPapersResourceWithStreamingResponse:
        from .resources.papers import AsyncPapersResourceWithStreamingResponse

        return AsyncPapersResourceWithStreamingResponse(self._client.papers)

    @cached_property
    def emails(self) -> emails.AsyncEmailsResourceWithStreamingResponse:
        from .resources.emails import AsyncEmailsResourceWithStreamingResponse

        return AsyncEmailsResourceWithStreamingResponse(self._client.emails)

    @cached_property
    def users(self) -> users.AsyncUsersResourceWithStreamingResponse:
        from .resources.users import AsyncUsersResourceWithStreamingResponse

        return AsyncUsersResourceWithStreamingResponse(self._client.users)

    @cached_property
    def assistant(self) -> assistant.AsyncAssistantResourceWithStreamingResponse:
        from .resources.assistant import AsyncAssistantResourceWithStreamingResponse

        return AsyncAssistantResourceWithStreamingResponse(self._client.assistant)

    @cached_property
    def folders(self) -> folders.AsyncFoldersResourceWithStreamingResponse:
        from .resources.folders import AsyncFoldersResourceWithStreamingResponse

        return AsyncFoldersResourceWithStreamingResponse(self._client.folders)

    @cached_property
    def comments(self) -> comments.AsyncCommentsResourceWithStreamingResponse:
        from .resources.comments import AsyncCommentsResourceWithStreamingResponse

        return AsyncCommentsResourceWithStreamingResponse(self._client.comments)

    @cached_property
    def analytics(self) -> analytics.AsyncAnalyticsResourceWithStreamingResponse:
        from .resources.analytics import AsyncAnalyticsResourceWithStreamingResponse

        return AsyncAnalyticsResourceWithStreamingResponse(self._client.analytics)

    @cached_property
    def search(self) -> search.AsyncSearchResourceWithStreamingResponse:
        from .resources.search import AsyncSearchResourceWithStreamingResponse

        return AsyncSearchResourceWithStreamingResponse(self._client.search)

    @cached_property
    def organizations(self) -> organizations.AsyncOrganizationsResourceWithStreamingResponse:
        from .resources.organizations import AsyncOrganizationsResourceWithStreamingResponse

        return AsyncOrganizationsResourceWithStreamingResponse(self._client.organizations)

    @cached_property
    def google_scholar(self) -> google_scholar.AsyncGoogleScholarResourceWithStreamingResponse:
        from .resources.google_scholar import AsyncGoogleScholarResourceWithStreamingResponse

        return AsyncGoogleScholarResourceWithStreamingResponse(self._client.google_scholar)

    @cached_property
    def arxiv(self) -> arxiv.AsyncArxivResourceWithStreamingResponse:
        from .resources.arxiv import AsyncArxivResourceWithStreamingResponse

        return AsyncArxivResourceWithStreamingResponse(self._client.arxiv)

    @cached_property
    def api_keys(self) -> api_keys.AsyncAPIKeysResourceWithStreamingResponse:
        from .resources.api_keys import AsyncAPIKeysResourceWithStreamingResponse

        return AsyncAPIKeysResourceWithStreamingResponse(self._client.api_keys)

    @cached_property
    def admin(self) -> admin.AsyncAdminResourceWithStreamingResponse:
        from .resources.admin import AsyncAdminResourceWithStreamingResponse

        return AsyncAdminResourceWithStreamingResponse(self._client.admin)

    @cached_property
    def wrapped(self) -> wrapped.AsyncWrappedResourceWithStreamingResponse:
        from .resources.wrapped import AsyncWrappedResourceWithStreamingResponse

        return AsyncWrappedResourceWithStreamingResponse(self._client.wrapped)

    @cached_property
    def notifications(self) -> notifications.AsyncNotificationsResourceWithStreamingResponse:
        from .resources.notifications import AsyncNotificationsResourceWithStreamingResponse

        return AsyncNotificationsResourceWithStreamingResponse(self._client.notifications)

    @cached_property
    def sitemaps(self) -> sitemaps.AsyncSitemapsResourceWithStreamingResponse:
        from .resources.sitemaps import AsyncSitemapsResourceWithStreamingResponse

        return AsyncSitemapsResourceWithStreamingResponse(self._client.sitemaps)

    @cached_property
    def retrieve(self) -> retrieve.AsyncRetrieveResourceWithStreamingResponse:
        from .resources.retrieve import AsyncRetrieveResourceWithStreamingResponse

        return AsyncRetrieveResourceWithStreamingResponse(self._client.retrieve)

    @cached_property
    def retool(self) -> retool.AsyncRetoolResourceWithStreamingResponse:
        from .resources.retool import AsyncRetoolResourceWithStreamingResponse

        return AsyncRetoolResourceWithStreamingResponse(self._client.retool)

    @cached_property
    def briefs(self) -> briefs.AsyncBriefsResourceWithStreamingResponse:
        from .resources.briefs import AsyncBriefsResourceWithStreamingResponse

        return AsyncBriefsResourceWithStreamingResponse(self._client.briefs)

    @cached_property
    def research(self) -> research.AsyncResearchResourceWithStreamingResponse:
        from .resources.research import AsyncResearchResourceWithStreamingResponse

        return AsyncResearchResourceWithStreamingResponse(self._client.research)

    @cached_property
    def mcp(self) -> mcp.AsyncMcpResourceWithStreamingResponse:
        from .resources.mcp import AsyncMcpResourceWithStreamingResponse

        return AsyncMcpResourceWithStreamingResponse(self._client.mcp)

    @cached_property
    def events(self) -> events.AsyncEventsResourceWithStreamingResponse:
        from .resources.events import AsyncEventsResourceWithStreamingResponse

        return AsyncEventsResourceWithStreamingResponse(self._client.events)

    @cached_property
    def well_known(self) -> well_known.AsyncWellKnownResourceWithStreamingResponse:
        from .resources.well_known import AsyncWellKnownResourceWithStreamingResponse

        return AsyncWellKnownResourceWithStreamingResponse(self._client.well_known)


Client = AlphaxivCat

AsyncClient = AsyncAlphaxivCat



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["V3UploadAvatarResponse", "Data"]


class Data(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class V3UploadAvatarResponse(BaseModel):
    data: List[Data]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3SearchResponse", "User", "UserAvatar"]


class UserAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class User(BaseModel):
    id: str

    avatar: Optional[List[UserAvatar]] = None

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    username: str

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")


class V3SearchResponse(BaseModel):
    users: List[User]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .topic_list_response import TopicListResponse as TopicListResponse
from .topic_toggle_params import TopicToggleParams as TopicToggleParams
from .topic_toggle_response import TopicToggleResponse as TopicToggleResponse
from .organization_list_response import OrganizationListResponse as OrganizationListResponse
from .organization_toggle_params import OrganizationToggleParams as OrganizationToggleParams
from .organization_toggle_response import OrganizationToggleResponse as OrganizationToggleResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SeenGetSeenResponse"]


class SeenGetSeenResponse(BaseModel):
    seen_paper_group_ids: List[str] = FieldInfo(alias="seenPaperGroupIds")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3AddPapersResponse"]


class V3AddPapersResponse(BaseModel):
    added_count: float = FieldInfo(alias="addedCount")

    duplicate_count: float = FieldInfo(alias="duplicateCount")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers import v2_comment_params
from ...types.papers.v2_comment_response import V2CommentResponse

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)

    def comment(
        self,
        version: str,
        *,
        anchor_position: Optional[v2_comment_params.AnchorPosition],
        body: str,
        focus_position: Optional[v2_comment_params.FocusPosition],
        highlight_rects: Optional[Iterable[v2_comment_params.HighlightRect]],
        parent_comment_id: Optional[str],
        selected_text: Optional[str],
        tag: Optional[Literal["anonymous", "general", "personal", "research", "resources"]],
        title: Optional[str],
        highlight_color: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2CommentResponse:
        """
        Add comment to paper version

        Source file: `api-server/src/controllers/papers/v2/add-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not version:
            raise ValueError(f"Expected a non-empty value for `version` but received {version!r}")
        return self._post(
            f"/papers/v2/{version}/comment",
            body=maybe_transform(
                {
                    "anchor_position": anchor_position,
                    "body": body,
                    "focus_position": focus_position,
                    "highlight_rects": highlight_rects,
                    "parent_comment_id": parent_comment_id,
                    "selected_text": selected_text,
                    "tag": tag,
                    "title": title,
                    "highlight_color": highlight_color,
                },
                v2_comment_params.V2CommentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2CommentResponse,
        )


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)

    async def comment(
        self,
        version: str,
        *,
        anchor_position: Optional[v2_comment_params.AnchorPosition],
        body: str,
        focus_position: Optional[v2_comment_params.FocusPosition],
        highlight_rects: Optional[Iterable[v2_comment_params.HighlightRect]],
        parent_comment_id: Optional[str],
        selected_text: Optional[str],
        tag: Optional[Literal["anonymous", "general", "personal", "research", "resources"]],
        title: Optional[str],
        highlight_color: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2CommentResponse:
        """
        Add comment to paper version

        Source file: `api-server/src/controllers/papers/v2/add-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not version:
            raise ValueError(f"Expected a non-empty value for `version` but received {version!r}")
        return await self._post(
            f"/papers/v2/{version}/comment",
            body=await async_maybe_transform(
                {
                    "anchor_position": anchor_position,
                    "body": body,
                    "focus_position": focus_position,
                    "highlight_rects": highlight_rects,
                    "parent_comment_id": parent_comment_id,
                    "selected_text": selected_text,
                    "tag": tag,
                    "title": title,
                    "highlight_color": highlight_color,
                },
                v2_comment_params.V2CommentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2CommentResponse,
        )


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.comment = to_raw_response_wrapper(
            v2.comment,
        )


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.comment = async_to_raw_response_wrapper(
            v2.comment,
        )


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.comment = to_streamed_response_wrapper(
            v2.comment,
        )


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.comment = async_to_streamed_response_wrapper(
            v2.comment,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["VersionRequestAITranslationResponse"]


class VersionRequestAITranslationResponse(BaseModel):
    data: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["ArchiveCreateResponse"]


class ArchiveCreateResponse(BaseModel):
    count: float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["UserGetPrivateNotesResponse", "Data"]


class Data(BaseModel):
    comments: List[Optional[object]]

    total: float


class UserGetPrivateNotesResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V2CommentParams", "AnchorPosition", "FocusPosition", "HighlightRect", "HighlightRectRect"]


class V2CommentParams(TypedDict, total=False):
    anchor_position: Required[Annotated[Optional[AnchorPosition], PropertyInfo(alias="anchorPosition")]]

    body: Required[str]

    focus_position: Required[Annotated[Optional[FocusPosition], PropertyInfo(alias="focusPosition")]]

    highlight_rects: Required[Annotated[Optional[Iterable[HighlightRect]], PropertyInfo(alias="highlightRects")]]

    parent_comment_id: Required[Annotated[Optional[str], PropertyInfo(alias="parentCommentId")]]

    selected_text: Required[Annotated[Optional[str], PropertyInfo(alias="selectedText")]]

    tag: Required[Optional[Literal["anonymous", "general", "personal", "research", "resources"]]]

    title: Required[Optional[str]]

    highlight_color: Annotated[Optional[str], PropertyInfo(alias="highlightColor")]


class AnchorPosition(TypedDict, total=False):
    offset: Required[float]

    page_index: Required[Annotated[float, PropertyInfo(alias="pageIndex")]]

    span_index: Required[Annotated[float, PropertyInfo(alias="spanIndex")]]


class FocusPosition(TypedDict, total=False):
    offset: Required[float]

    page_index: Required[Annotated[float, PropertyInfo(alias="pageIndex")]]

    span_index: Required[Annotated[float, PropertyInfo(alias="spanIndex")]]


class HighlightRectRect(TypedDict, total=False):
    x1: Required[float]

    x2: Required[float]

    y1: Required[float]

    y2: Required[float]


class HighlightRect(TypedDict, total=False):
    page_index: Required[Annotated[float, PropertyInfo(alias="pageIndex")]]

    rects: Required[Iterable[HighlightRectRect]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["V3RetrieveUnrelatedParams"]


class V3RetrieveUnrelatedParams(TypedDict, total=False):
    limit: Required[str]

    papers: Required[str]

    topics: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v4_subscribe_params import V4SubscribeParams as V4SubscribeParams
from .v4_unsubscribe_params import V4UnsubscribeParams as V4UnsubscribeParams
from .v4_list_notifications_response import V4ListNotificationsResponse as V4ListNotificationsResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .paper import (
    PaperResource,
    AsyncPaperResource,
    PaperResourceWithRawResponse,
    AsyncPaperResourceWithRawResponse,
    PaperResourceWithStreamingResponse,
    AsyncPaperResourceWithStreamingResponse,
)

__all__ = [
    "PaperResource",
    "AsyncPaperResource",
    "PaperResourceWithRawResponse",
    "AsyncPaperResourceWithRawResponse",
    "PaperResourceWithStreamingResponse",
    "AsyncPaperResourceWithStreamingResponse",
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..._models import BaseModel

__all__ = ["V3RetrieveFiguresResponse"]


class V3RetrieveFiguresResponse(BaseModel):
    figures: List[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.folders.v3.shared_copy_response import SharedCopyResponse
from ....types.folders.v3.shared_retrieve_response import SharedRetrieveResponse

__all__ = ["SharedResource", "AsyncSharedResource"]


class SharedResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SharedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return SharedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SharedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return SharedResourceWithStreamingResponse(self)

    def retrieve(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SharedRetrieveResponse:
        """
        Get a folder that has been shared publicly, including nested child folders

        Source file:
        `api-server/src/controllers/folders/v3/get-shared-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return self._get(
            f"/folders/v3/shared/{folder_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SharedRetrieveResponse,
        )

    def copy(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SharedCopyResponse:
        """
        Copy a shared folder and all nested folders to your own library

        Source file:
        `api-server/src/controllers/folders/v3/copy-shared-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return self._post(
            f"/folders/v3/shared/{folder_id}/copy",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SharedCopyResponse,
        )


class AsyncSharedResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSharedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSharedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSharedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncSharedResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SharedRetrieveResponse:
        """
        Get a folder that has been shared publicly, including nested child folders

        Source file:
        `api-server/src/controllers/folders/v3/get-shared-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return await self._get(
            f"/folders/v3/shared/{folder_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SharedRetrieveResponse,
        )

    async def copy(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SharedCopyResponse:
        """
        Copy a shared folder and all nested folders to your own library

        Source file:
        `api-server/src/controllers/folders/v3/copy-shared-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return await self._post(
            f"/folders/v3/shared/{folder_id}/copy",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SharedCopyResponse,
        )


class SharedResourceWithRawResponse:
    def __init__(self, shared: SharedResource) -> None:
        self._shared = shared

        self.retrieve = to_raw_response_wrapper(
            shared.retrieve,
        )
        self.copy = to_raw_response_wrapper(
            shared.copy,
        )


class AsyncSharedResourceWithRawResponse:
    def __init__(self, shared: AsyncSharedResource) -> None:
        self._shared = shared

        self.retrieve = async_to_raw_response_wrapper(
            shared.retrieve,
        )
        self.copy = async_to_raw_response_wrapper(
            shared.copy,
        )


class SharedResourceWithStreamingResponse:
    def __init__(self, shared: SharedResource) -> None:
        self._shared = shared

        self.retrieve = to_streamed_response_wrapper(
            shared.retrieve,
        )
        self.copy = to_streamed_response_wrapper(
            shared.copy,
        )


class AsyncSharedResourceWithStreamingResponse:
    def __init__(self, shared: AsyncSharedResource) -> None:
        self._shared = shared

        self.retrieve = async_to_streamed_response_wrapper(
            shared.retrieve,
        )
        self.copy = async_to_streamed_response_wrapper(
            shared.copy,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V3GetCurrentUserResponse",
    "Badges",
    "Preferences",
    "PreferencesBanner",
    "PreferencesBase",
    "PreferencesBaseAssistantCustomStyle",
    "PreferencesEmail",
    "PreferencesFolder",
    "User",
    "UserAvatar",
    "UserPreferences",
    "UserPreferencesBanner",
    "UserPreferencesBase",
    "UserPreferencesBaseAssistantCustomStyle",
    "UserPreferencesEmail",
    "UserPreferencesFolder",
    "UserPushSubscription",
    "UserSemanticScholar",
    "UserFeatured",
]


class Badges(BaseModel):
    site: int


class PreferencesBanner(BaseModel):
    id: str

    link: Optional[str] = None

    name: str

    type: Literal["success", "info", "warning", "error"]


class PreferencesBaseAssistantCustomStyle(BaseModel):
    id: str

    instructions: str

    name: str


class PreferencesBase(BaseModel):
    assistant_custom_styles: List[PreferencesBaseAssistantCustomStyle] = FieldInfo(alias="assistantCustomStyles")

    assistant_style_selection: Union[Literal["default", "concise", "tutor", "thorough", "skeptical"], str] = FieldInfo(
        alias="assistantStyleSelection"
    )

    default_private_paper_sidebar_tab: Optional[Literal["assistant", "notes", "similar"]] = FieldInfo(
        alias="defaultPrivatePaperSidebarTab", default=None
    )

    default_public_paper_sidebar_tab: Optional[Literal["comments", "assistant", "similar", "notes", "social"]] = (
        FieldInfo(alias="defaultPublicPaperSidebarTab", default=None)
    )

    feed_sort: Literal["Hot", "Comments", "Views", "Likes", "GitHub", "Twitter (X)", "Recommended"] = FieldInfo(
        alias="feedSort"
    )

    is_dark_mode_enabled: bool = FieldInfo(alias="isDarkModeEnabled")

    is_debug_mode_enabled: bool = FieldInfo(alias="isDebugModeEnabled")

    is_members_sidebar_visible: bool = FieldInfo(alias="isMembersSidebarVisible")

    preferred_language: Optional[
        Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
    ] = FieldInfo(alias="preferredLanguage", default=None)

    preferred_llm_model: Optional[str] = FieldInfo(alias="preferredLlmModel", default=None)

    reading_mode_enabled: bool = FieldInfo(alias="readingModeEnabled")

    show_model_thinking: bool = FieldInfo(alias="showModelThinking")

    tooling_pane_width: Optional[float] = FieldInfo(alias="toolingPaneWidth", default=None)

    web_search: Literal["off", "full"] = FieldInfo(alias="webSearch")


class PreferencesEmail(BaseModel):
    bounced: bool

    direct_notifications: bool = FieldInfo(alias="directNotifications")

    relevant_activity: bool = FieldInfo(alias="relevantActivity")


class PreferencesFolder(BaseModel):
    folder_id: str = FieldInfo(alias="folderId")

    opened: bool


class Preferences(BaseModel):
    banners: List[PreferencesBanner]

    base: PreferencesBase

    email: PreferencesEmail

    folders: List[PreferencesFolder]


class UserAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class UserPreferencesBanner(BaseModel):
    id: str

    link: Optional[str] = None

    name: str

    type: Literal["success", "info", "warning", "error"]


class UserPreferencesBaseAssistantCustomStyle(BaseModel):
    id: str

    instructions: str

    name: str


class UserPreferencesBase(BaseModel):
    assistant_custom_styles: List[UserPreferencesBaseAssistantCustomStyle] = FieldInfo(alias="assistantCustomStyles")

    assistant_style_selection: Union[Literal["default", "concise", "tutor", "thorough", "skeptical"], str] = FieldInfo(
        alias="assistantStyleSelection"
    )

    default_private_paper_sidebar_tab: Optional[Literal["assistant", "notes", "similar"]] = FieldInfo(
        alias="defaultPrivatePaperSidebarTab", default=None
    )

    default_public_paper_sidebar_tab: Optional[Literal["comments", "assistant", "similar", "notes", "social"]] = (
        FieldInfo(alias="defaultPublicPaperSidebarTab", default=None)
    )

    feed_sort: Literal["Hot", "Comments", "Views", "Likes", "GitHub", "Twitter (X)", "Recommended"] = FieldInfo(
        alias="feedSort"
    )

    is_dark_mode_enabled: bool = FieldInfo(alias="isDarkModeEnabled")

    is_debug_mode_enabled: bool = FieldInfo(alias="isDebugModeEnabled")

    is_members_sidebar_visible: bool = FieldInfo(alias="isMembersSidebarVisible")

    preferred_language: Optional[
        Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
    ] = FieldInfo(alias="preferredLanguage", default=None)

    preferred_llm_model: Optional[str] = FieldInfo(alias="preferredLlmModel", default=None)

    reading_mode_enabled: bool = FieldInfo(alias="readingModeEnabled")

    show_model_thinking: bool = FieldInfo(alias="showModelThinking")

    tooling_pane_width: Optional[float] = FieldInfo(alias="toolingPaneWidth", default=None)

    web_search: Literal["off", "full"] = FieldInfo(alias="webSearch")


class UserPreferencesEmail(BaseModel):
    bounced: bool

    direct_notifications: bool = FieldInfo(alias="directNotifications")

    relevant_activity: bool = FieldInfo(alias="relevantActivity")


class UserPreferencesFolder(BaseModel):
    folder_id: str = FieldInfo(alias="folderId")

    opened: bool


class UserPreferences(BaseModel):
    banners: List[UserPreferencesBanner]

    base: UserPreferencesBase

    email: UserPreferencesEmail

    folders: List[UserPreferencesFolder]


class UserPushSubscription(BaseModel):
    auth_key: str = FieldInfo(alias="authKey")

    endpoint: str

    p256dh_key: str = FieldInfo(alias="p256dhKey")


class UserSemanticScholar(BaseModel):
    id: str

    citation_count: Optional[float] = FieldInfo(alias="citationCount", default=None)

    external_ids: Optional[List[Optional[object]]] = FieldInfo(alias="externalIds", default=None)

    h_index: Optional[float] = FieldInfo(alias="hIndex", default=None)

    homepage: Optional[str] = None

    paper_count: Optional[float] = FieldInfo(alias="paperCount", default=None)


class UserFeatured(BaseModel):
    event_id: Optional[str] = FieldInfo(alias="eventId", default=None)

    paper_version_id: Optional[str] = FieldInfo(alias="paperVersionId", default=None)

    type: Literal["video", "paper"]


class User(BaseModel):
    id: str

    avatar: Optional[List[UserAvatar]] = None

    biography: Optional[str] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    email: str

    first_login: bool = FieldInfo(alias="firstLogin")

    follower_count: float = FieldInfo(alias="followerCount")

    following_count: float = FieldInfo(alias="followingCount")

    following_topics: List[str] = FieldInfo(alias="followingTopics")

    following_topics_count: float = FieldInfo(alias="followingTopicsCount")

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    location: Optional[str] = None

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    preferences: UserPreferences

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    push_subscriptions: List[UserPushSubscription] = FieldInfo(alias="pushSubscriptions")

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    requested_implementations: List[str] = FieldInfo(alias="requestedImplementations")

    role: Literal["user", "reviewer", "admin", "bot"]

    semantic_scholar: Optional[UserSemanticScholar] = FieldInfo(alias="semanticScholar", default=None)

    username: str

    verified: bool

    voted_paper_groups: List[str] = FieldInfo(alias="votedPaperGroups")

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)

    featured: Optional[List[UserFeatured]] = None

    following_organizations: Optional[List[str]] = FieldInfo(alias="followingOrganizations", default=None)


class V3GetCurrentUserResponse(BaseModel):
    badges: Badges

    preferences: Preferences

    user: User



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["SitemapListUsersResponse", "Data", "DataPagination", "DataUser"]


class DataPagination(BaseModel):
    total: float

    limit: Optional[float] = None

    page: Optional[float] = None


class DataUser(BaseModel):
    id: str

    username: str


class Data(BaseModel):
    pagination: DataPagination

    users: List[DataUser]


class SitemapListUsersResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .following_list_response import FollowingListResponse as FollowingListResponse
from .citation_get_graph_response import CitationGetGraphResponse as CitationGetGraphResponse
from .by_username_get_user_response import ByUsernameGetUserResponse as ByUsernameGetUserResponse
from .citation_get_summary_response import CitationGetSummaryResponse as CitationGetSummaryResponse
from .semantic_scholar_link_response import SemanticScholarLinkResponse as SemanticScholarLinkResponse
from .semantic_scholar_scrape_response import SemanticScholarScrapeResponse as SemanticScholarScrapeResponse
from .by_username_get_profile_page_response import ByUsernameGetProfilePageResponse as ByUsernameGetProfilePageResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["PaperFastSearchParams"]


class PaperFastSearchParams(TypedDict, total=False):
    include_private: Required[Annotated[Literal["true", "false"], PropertyInfo(alias="includePrivate")]]

    q: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3RetrieveAllResponse"]


class V3RetrieveAllResponse(BaseModel):
    limit: float

    skip: float

    universal_ids: List[str] = FieldInfo(alias="universalIds")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["MessageListResponse", "MessageListResponseItem"]


class MessageListResponseItem(BaseModel):
    id: str

    content: Optional[str] = None

    feedback_category: Optional[str] = FieldInfo(alias="feedbackCategory", default=None)

    feedback_details: Optional[str] = FieldInfo(alias="feedbackDetails", default=None)

    feedback_type: Optional[Literal["upvote", "downvote"]] = FieldInfo(alias="feedbackType", default=None)

    kind: Optional[str] = None

    model: Optional[str] = None

    parent_message_id: Optional[str] = FieldInfo(alias="parentMessageId", default=None)

    selected_at: str = FieldInfo(alias="selectedAt")

    tool_use_id: Optional[str] = FieldInfo(alias="toolUseId", default=None)

    type: Literal[
        "tool_use",
        "tool_result_text",
        "tool_result_file",
        "input_file",
        "input_text",
        "output_reasoning",
        "output_text",
    ]

    trace: Optional[str] = None


MessageListResponse: TypeAlias = List[MessageListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ImplementationListResponse", "AlphaXivImplementation", "PaperResource"]


class AlphaXivImplementation(BaseModel):
    id: str

    type: Literal["github", "marimo"]

    url: str


class PaperResource(BaseModel):
    id: str

    description: Optional[str] = None

    language: Optional[str] = None

    source: Literal["author", "other"]

    stars: float

    type: Literal["github", "marimo"]

    url: str


class ImplementationListResponse(BaseModel):
    alpha_xiv_implementations: List[AlphaXivImplementation] = FieldInfo(alias="alphaXivImplementations")

    paper_resources: List[PaperResource] = FieldInfo(alias="paperResources")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ....._models import BaseModel

__all__ = ["OrganizationToggleResponse"]


class OrganizationToggleResponse(BaseModel):
    following: bool

    organization: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["SemanticScholarScrapeResponse"]


class SemanticScholarScrapeResponse(BaseModel):
    message: str

    data: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ArchiveListParams"]


class ArchiveListParams(TypedDict, total=False):
    before: str
    """Decimal UNIX time in milliseconds"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.analytics import (
    PaperViewCountKickoffJobResponse,
    PaperViewCountProcessJobResponse,
    PaperViewCountIngestEventResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPaperViewCount:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_event(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = client.analytics.paper_view_count.ingest_event(
                paper_id="paperId",
            )

        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_event_with_all_params(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = client.analytics.paper_view_count.ingest_event(
                paper_id="paperId",
                created_at="createdAt",
                user_id="userId",
            )

        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_ingest_event(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.analytics.paper_view_count.with_raw_response.ingest_event(
                paper_id="paperId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = response.parse()
        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_ingest_event(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.analytics.paper_view_count.with_streaming_response.ingest_event(
                paper_id="paperId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper_view_count = response.parse()
                assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_job(self, client: AlphaxivCat) -> None:
        paper_view_count = client.analytics.paper_view_count.kickoff_job(
            type="type",
        )
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_job_with_all_params(self, client: AlphaxivCat) -> None:
        paper_view_count = client.analytics.paper_view_count.kickoff_job(
            type="type",
            like="like",
        )
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_job(self, client: AlphaxivCat) -> None:
        response = client.analytics.paper_view_count.with_raw_response.kickoff_job(
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = response.parse()
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_job(self, client: AlphaxivCat) -> None:
        with client.analytics.paper_view_count.with_streaming_response.kickoff_job(
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper_view_count = response.parse()
            assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_job(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = client.analytics.paper_view_count.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            )

        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_job_with_all_params(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = client.analytics.paper_view_count.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
                like=True,
            )

        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_job(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.analytics.paper_view_count.with_raw_response.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = response.parse()
        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_job(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.analytics.paper_view_count.with_streaming_response.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper_view_count = response.parse()
                assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncPaperViewCount:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_event(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = await async_client.analytics.paper_view_count.ingest_event(
                paper_id="paperId",
            )

        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_event_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = await async_client.analytics.paper_view_count.ingest_event(
                paper_id="paperId",
                created_at="createdAt",
                user_id="userId",
            )

        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_ingest_event(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.analytics.paper_view_count.with_raw_response.ingest_event(
                paper_id="paperId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = await response.parse()
        assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_ingest_event(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.analytics.paper_view_count.with_streaming_response.ingest_event(
                paper_id="paperId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper_view_count = await response.parse()
                assert_matches_type(PaperViewCountIngestEventResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_job(self, async_client: AsyncAlphaxivCat) -> None:
        paper_view_count = await async_client.analytics.paper_view_count.kickoff_job(
            type="type",
        )
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_job_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        paper_view_count = await async_client.analytics.paper_view_count.kickoff_job(
            type="type",
            like="like",
        )
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_job(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.analytics.paper_view_count.with_raw_response.kickoff_job(
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = await response.parse()
        assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_job(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.analytics.paper_view_count.with_streaming_response.kickoff_job(
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper_view_count = await response.parse()
            assert_matches_type(PaperViewCountKickoffJobResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_job(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = await async_client.analytics.paper_view_count.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            )

        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_job_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper_view_count = await async_client.analytics.paper_view_count.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
                like=True,
            )

        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_job(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.analytics.paper_view_count.with_raw_response.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper_view_count = await response.parse()
        assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_job(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.analytics.paper_view_count.with_streaming_response.process_job(
                paper_id="paperId",
                publication_date="publicationDate",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper_view_count = await response.parse()
                assert_matches_type(PaperViewCountProcessJobResponse, paper_view_count, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["V3GetClaimedPapersParams"]


class V3GetClaimedPapersParams(TypedDict, total=False):
    sort: Literal["date", "liked", "citations"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.papers.v3 import implementation_create_params, implementation_delete_params
from ....types.papers.v3.implementation_list_response import ImplementationListResponse
from ....types.papers.v3.implementation_create_response import ImplementationCreateResponse

__all__ = ["ImplementationsResource", "AsyncImplementationsResource"]


class ImplementationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ImplementationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return ImplementationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ImplementationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return ImplementationsResourceWithStreamingResponse(self)

    def create(
        self,
        paper_group_id: str,
        *,
        implementation_type: Literal["alphaxiv", "marimo", "author"],
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ImplementationCreateResponse:
        """
        Add an implementation (AlphaXiv, Marimo, Author, or Other)

        Source file:
        `api-server/src/controllers/papers/v3/add-implementation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return self._post(
            f"/papers/v3/{paper_group_id}/implementations",
            body=maybe_transform(
                {
                    "implementation_type": implementation_type,
                    "url": url,
                },
                implementation_create_params.ImplementationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ImplementationCreateResponse,
        )

    def list(
        self,
        paper_group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ImplementationListResponse:
        """
        Get all implementations for a paper (AlphaXiv, Marimo, Author, and Other)

        Source file:
        `api-server/src/controllers/papers/v3/get-implementations.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return self._get(
            f"/papers/v3/{paper_group_id}/implementations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ImplementationListResponse,
        )

    def delete(
        self,
        implementation_id: str,
        *,
        paper_group_id: str,
        type: Literal["alphaxiv", "resource"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an implementation (AlphaXiv, Marimo, Author, or Other)

        Source file:
        `api-server/src/controllers/papers/v3/delete-implementation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        if not implementation_id:
            raise ValueError(f"Expected a non-empty value for `implementation_id` but received {implementation_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/papers/v3/{paper_group_id}/implementations/{implementation_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"type": type}, implementation_delete_params.ImplementationDeleteParams),
            ),
            cast_to=NoneType,
        )


class AsyncImplementationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncImplementationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncImplementationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncImplementationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncImplementationsResourceWithStreamingResponse(self)

    async def create(
        self,
        paper_group_id: str,
        *,
        implementation_type: Literal["alphaxiv", "marimo", "author"],
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ImplementationCreateResponse:
        """
        Add an implementation (AlphaXiv, Marimo, Author, or Other)

        Source file:
        `api-server/src/controllers/papers/v3/add-implementation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return await self._post(
            f"/papers/v3/{paper_group_id}/implementations",
            body=await async_maybe_transform(
                {
                    "implementation_type": implementation_type,
                    "url": url,
                },
                implementation_create_params.ImplementationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ImplementationCreateResponse,
        )

    async def list(
        self,
        paper_group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ImplementationListResponse:
        """
        Get all implementations for a paper (AlphaXiv, Marimo, Author, and Other)

        Source file:
        `api-server/src/controllers/papers/v3/get-implementations.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return await self._get(
            f"/papers/v3/{paper_group_id}/implementations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ImplementationListResponse,
        )

    async def delete(
        self,
        implementation_id: str,
        *,
        paper_group_id: str,
        type: Literal["alphaxiv", "resource"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an implementation (AlphaXiv, Marimo, Author, or Other)

        Source file:
        `api-server/src/controllers/papers/v3/delete-implementation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        if not implementation_id:
            raise ValueError(f"Expected a non-empty value for `implementation_id` but received {implementation_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/papers/v3/{paper_group_id}/implementations/{implementation_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"type": type}, implementation_delete_params.ImplementationDeleteParams
                ),
            ),
            cast_to=NoneType,
        )


class ImplementationsResourceWithRawResponse:
    def __init__(self, implementations: ImplementationsResource) -> None:
        self._implementations = implementations

        self.create = to_raw_response_wrapper(
            implementations.create,
        )
        self.list = to_raw_response_wrapper(
            implementations.list,
        )
        self.delete = to_raw_response_wrapper(
            implementations.delete,
        )


class AsyncImplementationsResourceWithRawResponse:
    def __init__(self, implementations: AsyncImplementationsResource) -> None:
        self._implementations = implementations

        self.create = async_to_raw_response_wrapper(
            implementations.create,
        )
        self.list = async_to_raw_response_wrapper(
            implementations.list,
        )
        self.delete = async_to_raw_response_wrapper(
            implementations.delete,
        )


class ImplementationsResourceWithStreamingResponse:
    def __init__(self, implementations: ImplementationsResource) -> None:
        self._implementations = implementations

        self.create = to_streamed_response_wrapper(
            implementations.create,
        )
        self.list = to_streamed_response_wrapper(
            implementations.list,
        )
        self.delete = to_streamed_response_wrapper(
            implementations.delete,
        )


class AsyncImplementationsResourceWithStreamingResponse:
    def __init__(self, implementations: AsyncImplementationsResource) -> None:
        self._implementations = implementations

        self.create = async_to_streamed_response_wrapper(
            implementations.create,
        )
        self.list = async_to_streamed_response_wrapper(
            implementations.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            implementations.delete,
        )
